package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.EmsDeviceRbook;

/**
 * 设备台账Service接口
 * 
 * @author ruoyi
 * @date 2024-09-10
 */
public interface IEmsDeviceRbookService
{
    /**
     * 查询设备台账
     * 
     * @param id 设备台账主键
     * @return 设备台账
     */
     EmsDeviceRbook selectDeviceRbookById(Long id);

    /**
     * 查询设备台账列表
     * 
     * @param deviceRbook 设备台账
     * @return 设备台账集合
     */
     List<EmsDeviceRbook> selectDeviceRbookList(EmsDeviceRbook deviceRbook);

    /**
     * 新增设备台账
     * 
     * @param deviceRbook 设备台账
     * @return 结果
     */
     int insertDeviceRbook(EmsDeviceRbook deviceRbook);

    /**
     * 修改设备台账
     * 
     * @param deviceRbook 设备台账
     * @return 结果
     */
     int updateDeviceRbook(EmsDeviceRbook deviceRbook);

    /**
     * 批量删除设备台账
     * 
     * @param ids 需要删除的设备台账主键集合
     * @return 结果
     */
     int deleteDeviceRbookByIds(Long[] ids);

    /**
     * 删除设备台账信息
     * 
     * @param id 设备台账主键
     * @return 结果
     */
     int deleteDeviceRbookById(Long id);
}
